# pacote_texto

Description. 
The package pacote_texto is used to:
	- print hello world

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install package_name
```

## Usage

```python
from pacote_testpy_dio import hello
hello.world()
```

## Author
Douglas

## License
[MIT](https://choosealicense.com/licenses/mit/)